@@ -3,7 +3,7 @@
 # License: GPLv3 Copyright: 2010, Kovid Goyal <kovid at kovidgoyal.net>
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-import re
+import re, os
 from collections import namedtuple
 from functools import partial
 
@@ -163,7 +163,7 @@ def render_data(mi, use_roman_numbers=True, all_fields=False, pref_name='book_di
     return mi_to_html(
         mi, field_list=field_list, use_roman_numbers=use_roman_numbers, rtl=is_rtl(),
         rating_font=rating_font(), default_author_link=default_author_link(),
-        comments_heading_pos=gprefs['book_details_comments_heading_pos']
+        comments_heading_pos=gprefs['book_details_comments_heading_pos'], for_qt=True
     )
 
 # }}}
@@ -212,7 +212,7 @@ def add_format_entries(menu, data, book_info):
         else:
             m.addSeparator()
             m.addAction(_('Add other application for %s files...') % fmt.upper(), partial(book_info.choose_open_with, book_id, fmt))
-            m.addAction(_('Edit Open With applications...'), partial(edit_programs, fmt, book_info))
+            m.addAction(_('Edit Open with applications...'), partial(edit_programs, fmt, book_info))
             menu.addMenu(m)
             menu.ow = m
         if fmt.upper() in SUPPORTED:
@@ -220,6 +220,8 @@ def add_format_entries(menu, data, book_info):
             menu.addAction(_('Edit %s...') % fmt.upper(), partial(book_info.edit_fmt, book_id, fmt))
     path = data['path']
     if path:
+        if data.get('fname'):
+            path = os.path.join(path, data['fname'] + '.' + data['fmt'].lower())
         ac = book_info.copy_link_action
         ac.current_url = path
         ac.setText(_('&Copy path to file'))
@@ -276,10 +278,10 @@ def add_item_specific_entries(menu, data, book_info):
     return search_internet_added
 
 
-def details_context_menu_event(view, ev, book_info):
+def details_context_menu_event(view, ev, book_info, add_popup_action=False):
     url = view.anchorAt(ev.pos())
     menu = view.createStandardContextMenu()
-    menu.addAction(QIcon(I('edit-copy.png')), _('Copy &all'), partial(copy_all, book_info))
+    menu.addAction(QIcon(I('edit-copy.png')), _('Copy &all'), partial(copy_all, view))
     search_internet_added = False
     if url and url.startswith('action:'):
         data = json_loads(from_hex_bytes(url.split(':', 1)[1]))
@@ -296,6 +298,10 @@ def details_context_menu_event(view, ev, book_info):
     for ac in tuple(menu.actions()):
         if not ac.isEnabled():
             menu.removeAction(ac)
+    if add_popup_action:
+        menu.addSeparator()
+        ac = menu.addAction(_('Open the Book details window'))
+        ac.triggered.connect(book_info.show_book_info)
     if len(menu.actions()) > 0:
         menu.exec_(ev.globalPos())
 # }}}
@@ -631,7 +637,7 @@ class BookInfo(HTMLDisplay):
             return HTMLDisplay.mouseDoubleClickEvent(self, ev)
 
     def contextMenuEvent(self, ev):
-        details_context_menu_event(self, ev, self)
+        details_context_menu_event(self, ev, self, True)
 
     def open_with(self, book_id, fmt, entry):
         self.open_fmt_with.emit(book_id, fmt, entry)
@@ -766,7 +772,7 @@ class BookDetails(QWidget):  # {{{
 
     def dragEnterEvent(self, event):
         md = event.mimeData()
-        if dnd_has_extension(md, image_extensions() + BOOK_EXTENSIONS, allow_all_extensions=True) or \
+        if dnd_has_extension(md, image_extensions() + BOOK_EXTENSIONS, allow_all_extensions=True, allow_remote=True) or \
                 dnd_has_image(md):
             event.acceptProposedAction()
 
@@ -823,6 +829,7 @@ class BookDetails(QWidget):  # {{{
         self.cover_view.cover_removed.connect(self.cover_removed.emit)
         self._layout.addWidget(self.cover_view)
         self.book_info = BookInfo(vertical, self)
+        self.book_info.show_book_info = self.show_book_info
         self.book_info.search_internet = self.search_internet
         self.book_info.search_requested = self.search_requested.emit
         self._layout.addWidget(self.book_info)
